/**
 * Copyright 2020 Inrupt Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
 * Software, and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
import { Theme } from "@material-ui/core";
import { ThemeOptions } from "@material-ui/core/styles";
import { Typography, TypographyStyle } from "@material-ui/core/styles/createTypography";
import { JssStyle } from "jss";
import { Palette } from "@material-ui/core/styles/createPalette";
import { IconSetConfiguration, IconStyles } from "./icon";
export interface ThemeConfiguration extends ThemeOptions {
    name: string;
    label: string;
    localFonts?: Record<string, (path: string) => string>;
    stylesheets?: string[];
    licenses?: string[];
    iconSet: ThemeIcons;
}
export interface ThemeIcons {
    config: IconSetConfiguration;
    styles: (theme: PrismTheme) => IconStyles;
    iconColor: (color: string) => JssStyle;
}
interface PrismPalette extends Palette {
    adjustAlpha: (color: string, alpha: number) => string;
}
interface PrismTypography extends Typography {
    body: TypographyStyle;
    heading: TypographyStyle;
}
export interface PrismTheme extends Theme {
    icons: ThemeIcons;
    palette: PrismPalette;
    typography: PrismTypography;
}
export interface CreatePrismThemeOptions {
    icons: ThemeIcons;
}
export declare function createPrismTheme(configuration: ThemeConfiguration, options?: Partial<CreatePrismThemeOptions>, ...args: object[]): PrismTheme;
export {};
